id_extract: Generic Method for Extracting Posterior Samples

id_extractR Documentation

Generic Method for Extracting Posterior Samples

Description

This is a generic function.

Usage

id_extract(object, ...)

Arguments

object

A fitted idealstan object

...

Other arguments passed on to underlying functions

Details

This generic will extract the full stan posterior samples from idealstan objects.

See the corresponding method definition for more information about what you can acccess with this generic.

Value

A tibble of posterior draws, with rows as draws and columns as parameters.

Examples


data('senate114')
senate114$cast_code <- ifelse(senate114$cast_code=="Absent", NA,
                              as.integer(senate114$cast_code) - 1L)
sen_data <- id_make(senate114, outcome_disc='cast_code',
                    person_id='bioname', item_id='rollnumber',
                    group_id='party_code')
sen_est <- id_estimate(sen_data, model_type=1, fixtype='vb_full', use_method="pathfinder", ncores=4)
id_extract(sen_est, extract_type='persons')


idealstan documentation built on May 13, 2026, 1:08 a.m.