| id_plot_legis_dyn | R Documentation |
id_plot_legis_dyn() was renamed to id_plot_persons_dyn() for clarity and consistency.
id_plot_legis_dyn(
object,
return_data = FALSE,
include = NULL,
item_plot = NULL,
text_size_label = 2,
text_size_group = 2.5,
high_limit = 0.95,
low_limit = 0.05,
line_size = 1,
highlight = NULL,
plot_text = TRUE,
use_ci = TRUE,
plot_lines = 0,
draw_line_alpha = 0.5,
person_line_alpha = 0.3,
person_ci_alpha = 0.8,
item_plot_type = "non-inflated",
show_true = FALSE,
group_color = TRUE,
hpd_limit = 10,
sample_persons = NULL,
use_chain = NULL,
add_cov = TRUE,
...
)
object |
A fitted |
return_data |
If true, the calculated legislator/bill data is returned along with the plot in a list |
include |
Specify a list of person/legislator IDs to include in the plot (all others excluded) |
item_plot |
The value of the item/bill for which to plot its midpoint (character value) |
text_size_label |
ggplot2 text size for legislator labels |
text_size_group |
ggplot2 text size for group text used for points |
high_limit |
A number between 0 and 1 showing the upper limit to compute the posterior uncertainty interval (defaults to 0.95). |
low_limit |
A number between 0 and 1 showing the lower limit to compute the posterior uncertainty interval (defaults to 0.05). |
line_size |
Sets the size of the line of the time-varying ideal points. |
highlight |
A character referring to one of the persons in |
plot_text |
If |
use_ci |
Whether or not high-posterior density intervals (credible intervals) should be plotted over the estimates (turn off if the plot is too busy) |
plot_lines |
The number of lines of actual draws of time-varying ideal points to draw on the plot. Note that these are grouped by persons. Specific draws selected at random from total number of draws of the estimation. Default is 0. |
draw_line_alpha |
The opacity of lines plotted over the distribution (should be between 0 and 1, default is 0.5). |
person_line_alpha |
The transparency level of the time-varying ideal point line |
person_ci_alpha |
The transparency level of ribbon confidence interval around the time-varying ideal points |
item_plot_type |
Whether to show the |
show_true |
Whether to show the true values of the legislators (if model has been simulated) |
group_color |
If |
hpd_limit |
The greatest absolute difference in high-posterior density interval shown for any point. Useful for excluding imprecisely estimated persons/legislators from the plot. Leave NULL if you don't want to exclude any. |
sample_persons |
If you don't want to use the full number of persons/legislators from the model, enter a proportion (between 0 and 1) to select
only a fraction of the persons/legislators.
(see |
use_chain |
ID of MCMC chain to use rather than combining all chains. Default is NULL which will use all chains and is recommended. |
add_cov |
Whether to add values of hierarchical person-level covariates to the time trends (defaults to TRUE). |
... |
Other options passed on to plotting function, currently ignored |
A ggplot2 object showing dynamic legislator/person ideal points over time. Deprecated;
use id_plot_persons_dyn instead.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.