id_plot_rhats: Plotting Function to Display Rhat Distribution

View source: R/Plot.R

id_plot_rhatsR Documentation

Plotting Function to Display Rhat Distribution

Description

This plotting function displays a histogram of the Rhat values of all parameters in an idealstan model.

Usage

id_plot_rhats(obj)

Arguments

obj

A fitted idealstan object.

Value

A ggplot2 histogram showing the distribution of Rhat convergence statistics for all parameters in the model.

Examples


sim <- id_sim_gen()
est <- id_estimate(sim, model_type=1, fixtype='vb_full',
                   use_method="pathfinder", nchains=2, ncores=2)
id_plot_rhats(est)


idealstan documentation built on May 13, 2026, 1:08 a.m.