id_plot_sims: This function plots the results from a simulation generated...

View source: R/Plot.R

id_plot_simsR Documentation

This function plots the results from a simulation generated by id_sim_gen().

Description

This function plots the results from a simulation generated by id_sim_gen().

Usage

id_plot_sims(sims, type = "RMSE")

id_show_trues(sims, type = "RMSE")

Arguments

sims

A fitted idealstan object that has true data generated by id_sim_gen()

type

Type of analysis of true versus fitted values, can be 'RMSE', 'Residuals' or 'Coverage'

Value

A ggplot2 object showing RMSE, residuals, or coverage for simulated parameters compared to their true values.

Examples


sim <- id_sim_gen()
est <- id_estimate(sim, model_type=1, fixtype='vb_full',
                   use_method="pathfinder", nchains=2, ncores=2)
id_plot_sims(est)               # RMSE (default)
id_plot_sims(est, type='Residuals')
id_plot_sims(est, type='Coverage')


idealstan documentation built on May 13, 2026, 1:08 a.m.