idealstan-class: Results of 'id_estimate' function

idealstan-classR Documentation

Results of id_estimate function

Description

The idealstan objects store the results of estimations carried out by the id_estimate function. These objects include the full results of Bayesian sampling performed by the stan function in the rstan package.


idealstan documentation built on May 13, 2026, 1:08 a.m.