| id_plot_gbeta_prior | R Documentation |
This function starts an interactive Shiny application to visualize a generalized Beta distribution
on a symmetrical interval from -scale to +scale in order to calculate the distribution paramters alpha (the restrict_sd_high/restrict_N_low parameter to id_estimate) and beta (the restrict_N_high/restrict_sd_low parameter to id_estimate). This function is useful for understanding what values to use to pin item discrimination parameters in id_estimate given a specific prior mean initial_y and a relative level of precision prior_sample_size (also known as phi). Higher values of prior_sample_size will imply a tighter prior around the pinned discrimination parameter.
id_plot_gbeta_prior(initial_y = 0, prior_sample_size = 200, limits = c(-1, 1))
initial_y |
Initial observed variate |
prior_sample_size |
Relative level of precision/tightness around |
limits |
Limits of prior. Default is |
The function is also useful for calculating the prior for all non-constrained discrimination parameters as well (discrim_reg_shape and discrim_reg_scale). These parameters are denoted in the Shiny app output for easy cut and paste to the id_estimate function call.
A ggplot2 object showing the generalized Beta prior distribution for the selected
parameter values, or an interactive Shiny application if run interactively.
# Launch interactive Shiny app to explore the generalized Beta prior
if(interactive()) {
id_plot_gbeta_prior(initial_y=0.5, prior_sample_size=200)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.