| id_plot_rhats | R Documentation |
This plotting function displays a histogram of the Rhat values of all parameters in an idealstan model.
id_plot_rhats(obj)
obj |
A fitted |
A ggplot2 histogram showing the distribution of Rhat convergence statistics for all
parameters in the model.
sim <- id_sim_gen()
est <- id_estimate(sim, model_type=1, fixtype='vb_full',
use_method="pathfinder", nchains=2, ncores=2)
id_plot_rhats(est)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.