| id_plot_sims | R Documentation |
id_sim_gen().This function plots the results from a simulation generated by id_sim_gen().
id_plot_sims(sims, type = "RMSE")
id_show_trues(sims, type = "RMSE")
sims |
A fitted |
type |
Type of analysis of true versus fitted values, can be |
A ggplot2 object showing RMSE, residuals, or coverage for simulated parameters
compared to their true values.
sim <- id_sim_gen()
est <- id_estimate(sim, model_type=1, fixtype='vb_full',
use_method="pathfinder", nchains=2, ncores=2)
id_plot_sims(est) # RMSE (default)
id_plot_sims(est, type='Residuals')
id_plot_sims(est, type='Coverage')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.