| id_sim_coverage | R Documentation |
Function that computes how often the true value of the parameter is included within the 95/5 high posterior density interval
id_sim_coverage(obj, rep = 1, quantiles = c(0.95, 0.05))
obj |
A fitted |
rep |
How many times the models were fitted on new data, currently can only be 1 |
quantiles |
What the quantile coverage of the high posterior density interval should be |
A named list of tibble objects, one per parameter type
(Person Ideal Points, Absence Discriminations, Item Discrimations), each with
columns avg, high, low, Params, est_type, and iter
summarising posterior coverage of the true parameter values.
sim <- id_sim_gen()
est <- id_estimate(sim, model_type=1, fixtype='vb_full',
use_method="pathfinder", nchains=2, ncores=2)
cov <- id_sim_coverage(est)
# average coverage across all person ideal points
mean(cov[['Person Ideal Points']]$avg)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.