| id_sim_resid | R Documentation |
Residual function for checking estimated samples compared to true simulation scores Returns a data frame with residuals plus quantiles.
id_sim_resid(obj, rep = 1)
obj |
A fitted |
rep |
Over how many replicates to calculate residuals? Currently can only be 1 |
A named list of tibble objects, one per parameter type
(Ideal Points, Absence Discrimination, Item Discrimination), each with
columns avg, high, low, Params, est_type, and iter
summarising posterior residuals relative to true parameter values.
sim <- id_sim_gen()
est <- id_estimate(sim, model_type=1, fixtype='vb_full',
use_method="pathfinder", nchains=2, ncores=2)
id_sim_resid(est)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.