| id_sim_rmse | R Documentation |
RMSE function for calculating individual RMSE values compared to true simulation scores Returns a data frame with RMSE plus quantiles.
id_sim_rmse(obj, rep = 1)
obj |
A fitted |
rep |
Over how many replicates to calculate RMSE? Currently can only be 1 |
A named list of tibble objects, one per parameter type
(Ideal Points, Absence Discriminations, Item Discrimations), each with
columns avg, high, low, Params, est_type, and iter
summarising RMSE relative to true parameter values.
sim <- id_sim_gen()
est <- id_estimate(sim, model_type=1, fixtype='vb_full',
use_method="pathfinder", nchains=2, ncores=2)
id_sim_rmse(est)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.