| summary,idealstan-method | R Documentation |
idealstan objectThis function produces quantiles and standard deviations for the posterior samples of idealstan objects.
## S4 method for signature 'idealstan'
summary(
object,
pars = "ideal_pts",
high_limit = 0.95,
low_limit = 0.05,
aggregated = TRUE,
use_chain = NULL,
cores = 1
)
object |
An |
pars |
Either |
high_limit |
A number between 0 and 1 reflecting the upper limit of the uncertainty interval (defaults to 0.95). |
low_limit |
A number between 0 and 1 reflecting the lower limit of the uncertainty interval (defaults to 0.05). |
aggregated |
Whether to return summaries of the posterior values or the
full posterior samples. Defaults to |
use_chain |
ID of a specific MCMC chain to use. Default (NULL) is all the chains and is recommended. |
cores |
Number of cores to use for parallel processing when summarizing
item parameters. Defaults to 1 (no parallelization). Values greater than 1 use
|
A tibble data frame with parameters as rows and descriptive statistics as columns
data('senate114')
senate114$cast_code <- ifelse(senate114$cast_code=="Absent", NA,
as.integer(senate114$cast_code) - 1L)
sen_data <- id_make(senate114, outcome_disc='cast_code',
person_id='bioname', item_id='rollnumber',
group_id='party_code')
sen_est <- id_estimate(sen_data, model_type=1, fixtype='vb_full', use_method="pathfinder", ncores=4)
summary(sen_est, pars='ideal_pts')
summary(sen_est, pars='items')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.